@@ -15,7 +15,6 @@ class GameTag(IntEnum):
 	TURN_START = 8
 	TURN_TIMER_SLUSH = 9
 	PREMIUM = 12
-	GOLD_REWARD_STATE = 13
 	PLAYSTATE = 17
 	LAST_AFFECTED_BY = 18
 	STEP = 19
@@ -265,6 +264,7 @@ class GameTag(IntEnum):
 	EMPOWERED_TREASURE = 646
 	ONE_SIDED_GHOSTLY = 648
 	CURRENT_NEGATIVE_SPELLPOWER = 651
+	DONT_PICK_FROM_SUBSETS = 676
 	IS_VAMPIRE = 680
 	CORRUPTED = 681
 	HIDE_HEALTH = 682
@@ -298,7 +298,7 @@ class GameTag(IntEnum):
 	HERO_EMOTE_SILENCED = 832
 	MINION_IN_HAND_BUFF = 845
 	ECHO = 846
-	MODULAR = 849
+	MAGNETIC = 849
 	IGNORE_HIDE_STATS_FOR_BIG_CARD = 857
 	REAL_TIME_TRANSFORM = 859
 	WAIT_FOR_PLAYER_RECONNECT_PERIOD = 860
@@ -338,6 +338,7 @@ class GameTag(IntEnum):
 	END_TURN_BUTTON_ALTERNATIVE_APPEARANCE = 1000
 	WAND = 1015
 	TREAT_AS_PLAYED_HERO_CARD = 1016
+	LITERALLY_UNPLAYABLE = 1020
 	NUM_HERO_POWER_DAMAGE_THIS_GAME = 1025
 	PUZZLE_NAME = 1026
 	TURN_INDICATOR_ALTERNATIVE_APPEARANCE = 1027
@@ -443,7 +444,6 @@ class GameTag(IntEnum):
 	DECK_RULE_COUNT_AS_COPY_OF_CARD_ID = 1413
 	STUDY = 1414
 	BACON_ODD_PLAYER_OUT = 1415
-	BACON_MINION_IS_LEVEL_TWO = 1421
 	BACON_IS_KEL_THUZAD = 1423
 	HIGHLIGHT_ATTACKING_MINION_DURING_COMBAT = 1424
 	SPELLBURST = 1427
@@ -466,7 +466,8 @@ class GameTag(IntEnum):
 	ALWAYS_USE_FAST_ACTOR_TRIGGERS = 1473
 	PIECE_OF_CTHUN = 1477
 	BACON_HERO_CAN_BE_DRAFTED = 1491
-	DISABLE_GOLDEN_ANIMATIONS = 1514
+	TRANSIENT_ENTITY = 1493
+	DISABLE_NONHERO_GOLDEN_ANIMATIONS = 1514
 	WATERMARK_OVERRIDE_CARD_SET = 1517
 	DORMANT = 1518
 	DORMANT_AWAKEN_CONDITION_ENCHANT = 1519
@@ -481,6 +482,7 @@ class GameTag(IntEnum):
 	SPAWN_TIME_COUNT = 1556
 	SKIP_MULLIGAN = 1561
 	COPIED_FROM_ENTITY_ID = 1565
+	BACON_SELL_VALUE = 1587
 	BACON_VERDANTSPHERES = 1598
 	OPPONENT_SIDE_GHOSTLY = 1609
 	FORCE_NO_CUSTOM_LIFETIME_SPELLS = 1613
@@ -494,6 +496,7 @@ class GameTag(IntEnum):
 	COIN_MANA_GEM_FOR_CHOICE_CARDS = 1643
 	METAMORPHOSIS = 1644
 	HERO_POWER_ENTITY = 1646
+	BACON_PLAYER_RESULTS_HERO_OVERRIDE = 1649
 	DISCOVER_STUDIES_VISUAL = 1650
 	LETTUCE_CONTROLLER = 1653
 	LETTUCE_ABILITY_OWNER = 1654
@@ -520,6 +523,7 @@ class GameTag(IntEnum):
 	LETTUCE_MAX_IN_PLAY_MERCENARIES = 1704
 	LETTUCE_MERCENARIES_TO_NOMINATE = 1705
 	LETTUCE_COOLDOWN_WHILE_BENCHED = 1708
+	LETTUCE_COMBAT_FROM_HIGH_TO_LOW = 1712
 	PENDING_TRANSFORM_TO_CARD = 1716
 	TRANSFORMED_FROM_CARD_VISUAL_TYPE = 1719
 	TRADEABLE = 1720
@@ -550,13 +554,16 @@ class GameTag(IntEnum):
 	LETTUCE_NODE_TYPE = 1808
 	SHOW_DISCOVER_FROM_DECK = 1816
 	MINI_SET = 1824
+	ARMOR_GAINED_THIS_GAME = 1828
 	CANT_TRIGGER_DEATHRATTLE = 1831
+	BACON_BLOODGEMBUFFATKVALUE = 1844
 	CANT_MOVE_MINION = 1848
 	LETTUCE_MERCENARY_EXPERIENCE = 1852
 	LETTUCE_IS_EQUPIMENT = 1855
 	LETTUCE_EQUIPMENT_ID = 1856
 	DARKMOON_FAIRE_PRIZES_ACTIVE = 1895
 	IGNORE_DECK_RULESET = 1896
+	HONORABLEKILL = 1920
 	HAS_DIAMOND_QUALITY = 1932
 	CURRENT_SPELLPOWER_ARCANE = 1936
 	CURRENT_SPELLPOWER_FIRE = 1937
@@ -576,17 +583,20 @@ class GameTag(IntEnum):
 	SPELLPOWER_FEL = 1951
 	SPELLPOWER_PHYSICAL = 1952
 	ENRAGED_TOOLTIP = 1954
+	IMP = 1965
 	BLOOD_GEM = 1966
 	LETTUCE_HAS_MANUALLY_SELECTED_ABILITY = 1967
 	LETTUCE_KEEP_LAST_STANDING_MINION_ACTOR = 1976
 	GOLDSPARKLES_HINT = 1984
 	LETTUCE_USE_DETERMINISTIC_TEAM_ABILITY_QUEUING = 1990
+	LETTUCE_SELECTED_ABILITY_QUEUE_ORDER = 1991
 	QUESTLINE_FINAL_REWARD_DATABASE_ID = 1992
 	QUESTLINE_PART = 1993
 	QUESTLINE_REQUIREMENT_MET_1 = 1994
 	QUESTLINE_REQUIREMENT_MET_2 = 1995
 	QUESTLINE_REQUIREMENT_MET_3 = 1996
 	DONT_SHOW_IN_HISTORY = 2015
+	MAX_SLOTS_PER_PLAYER_OVERRIDE = 2017
 	FAKE_CONTROLLER = 2032
 	BACON_SKIN = 2038
 	BACON_SKIN_PARENT_ID = 2039
@@ -595,8 +605,11 @@ class GameTag(IntEnum):
 	BACON_BOB_SKIN = 2049
 	BACON_COMBAT_DAMAGE_CAP = 2089
 	REFRESH = 2104
+	TARGETING_ARROW_TYPE = 2108
 	LETTUCE_CURRENT_BOUNTY_ID = 2120
+	LETTUCE_OVERTIME = 2123
 	AVENGE = 2129
+	BACON_COMPANION_ID = 2130
 	SPELLRESISTANCE_ARCANE = 2138
 	SPELLRESISTANCE_FIRE = 2139
 	SPELLRESISTANCE_FROST = 2140
@@ -611,6 +624,7 @@ class GameTag(IntEnum):
 	SPELLWEAKNESS_HOLY = 2149
 	SPELLWEAKNESS_SHADOW = 2150
 	SPELLWEAKNESS_FEL = 2151
+	BACON_BUDDY = 2154
 	BACON_STARSTOBOUNCEOFF = 2155
 	LETTUCE_ATTACK = 2159
 	LETTUCE_SPELLCOMBO = 2160
@@ -626,12 +640,168 @@ class GameTag(IntEnum):
 	ROOTED = 2179
 	VULNERABLE = 2180
 	DEATHBLOW = 2185
+	CORPSES = 2186
+	MAXRESOURCES_BLOOD = 2188
+	MAXRESOURCES_FROST = 2189
+	MAXRESOURCES_UNHOLY = 2190
+	MAXRESOURCES_DEATH = 2191
+	RESOURCES_BLOOD = 2192
+	RESOURCES_FROST = 2193
+	RESOURCES_UNHOLY = 2194
+	RESOURCES_DEATH = 2195
+	COST_BLOOD = 2196
+	COST_FROST = 2197
+	COST_UNHOLY = 2198
+	COST_DEATH = 2199
+	HAS_BLOOD_PLAGUE = 2211
+	HAS_FROST_PLAGUE = 2212
+	HAS_UNHOLY_PLAGUE = 2213
 	BLEED = 2214
 	CRITICALDAMAGE = 2219
 	ROOT = 2220
 	LETTUCE_SHOW_OPPOSING_FAKE_HAND = 2224
+	BACON_DIABLO_FIGHT_DIABLO_PLAYER_ID = 2226
 	LETTUCE_VERSUS_SPELL_STATE = 2228
 	LETTUCE_START_OF_GAME_ABILITY = 2241
+	COLOSSAL = 2247
+	COLOSSAL_LIMB = 2248
+	CURRENT_TEMP_SPELLPOWER_ARCANE = 2250
+	CURRENT_TEMP_SPELLPOWER_FEL = 2251
+	CURRENT_TEMP_SPELLPOWER_FIRE = 2252
+	CURRENT_TEMP_SPELLPOWER_FROST = 2253
+	CURRENT_TEMP_SPELLPOWER_NATURE = 2254
+	CURRENT_TEMP_SPELLPOWER_HOLY = 2255
+	CURRENT_TEMP_SPELLPOWER_PHYSICAL = 2256
+	CURRENT_TEMP_SPELLPOWER_SHADOW = 2257
+	CURRENT_TEMP_SPELLPOWER = 2258
+	BACON_CHOSEN_BOARD_SKIN_ID = 2264
+	LETTUCE_ALLIANCE = 2279
+	LETTUCE_HORDE = 2280
+	OBJECTIVE = 2311
+	LETTUCE_REFRESH = 2312
+	LETTUCE_ELVES = 2322
+	OBJECTIVE_AURA = 2329
+	DREDGE = 2332
+	CURRENT_HEALING_POWER = 2333
+	EARLY_CONCEDE_POPUP_AVAILABLE = 2340
+	BACON_PLAYER_NUM_HERO_BUDDIES_GAINED = 2346
+	BATTLEGROUNDS_FAVORITE_FINISHER = 2348
+	LOCATION_ACTION_COST = 2352
+	LOCATION_ACTION_COOLDOWN = 2353
+	WHELP = 2355
+	SPELLCRAFT = 2359
+	BACON_HERO_BUDDY_PROGRESS = 2364
+	REVIVE = 2369
+	BACON_HEROPOWER_BASE_HERO_ID = 2376
+	LETTUCE_CURSED_ABILITY_VISUAL = 2381
+	BACON_OMIT_WHEN_OUT_OF_ROTATION = 2387
+	ALLIED = 2388
+	LETTUCE_HEALINGPOWER = 2434
+	DONT_SUPPRESS_SUMMON_VO = 2440
+	BACON_NUMBER_HERO_REFRESH_AVAILABLE = 2452
+	BACON_FREEZE_TOOLTIP = 2455
+	INFUSE = 2456
+	INFUSED = 2457
+	HAS_DRAG_TO_BUY = 2458
+	ENTITY_TAG_THRESHOLD_TAG_ID = 2459
+	ENTITY_TAG_THRESHOLD_VALUE = 2460
+	MERCS_SPELLWEAKNESS = 2464
+	MERCS_SPELLRESISTANCE = 2465
+	BACON_QUESTS_ACTIVE = 2468
+	COLOSSAL_LIMB_ON_LEFT = 2469
+	LETTUCE_ABILITY_TILE_VISUAL_PUBLIC_SPEED = 2470
+	BACON_DIED_LAST_COMBAT = 2483
+	LETTUCE_ABILITY_TIER = 2493
+	LETTUCE_EQUIPMENT_TIER = 2494
+	MANATHIRST = 2498
+	IMMOLATING = 2505
+	MERCS_EXPLORER = 2510
+	BACON_BUDDY_ENABLED = 2518
+	BACON_EVOLUTION_CARD_ID = 2519
+	SPELLCRAFT_HINT = 2557
+	CORPSE = 2559
+	MERCS_BENCH = 2570
+	BACON_MINION_TYPE_REWARD = 2571
+	COPIED_HINT = 2572
+	BLEEDING = 2575
+	HAS_SIGNATURE_QUALITY = 2589
+	IMMOLATESTAGE = 2600
+	EVIL_TWIN_MUSTACHE = 2611
+	SINFUL_BRAND = 2613
+	LETTUCE_SILENCE = 2631
+	BACON_QUEST_COMPLETED = 2633
+	CORPSES_SPENT_THIS_GAME = 2639
+	HAUNTED_SECRET = 2634
+	DONT_SUPPRESS_KEYWORD_VO = 2636
+	CARD_BACK_OVERRIDE = 2637
+	CARDTEXT_ENTITY_0 = 2655
+	CARDTEXT_ENTITY_1 = 2656
+	CARDTEXT_ENTITY_2 = 2657
+	CARDTEXT_ENTITY_3 = 2658
+	CARDTEXT_ENTITY_4 = 2659
+	CARDTEXT_ENTITY_5 = 2660
+	CARDTEXT_ENTITY_6 = 2661
+	CARDTEXT_ENTITY_7 = 2662
+	CARDTEXT_ENTITY_8 = 2663
+	CARDTEXT_ENTITY_9 = 2664
+	NON_KEYWORD_SPELLBURST = 2672
+	BACON_CARD_DBID_REWARD = 2673
+	SECRET_LOCKED = 2676
+	BACON_STEALTH_TOOLTIP = 2704
+	BACON_QUEST_TOOLTIP = 2705
+	BACON_IS_HEROPOWER_QUESTREWARD = 2706
+	BACON_HERO_QUEST_REWARD_DATABASE_ID = 2713
+	BACON_HERO_HEROPOWER_QUEST_REWARD_DATABASE_ID = 2714
+	BACON_HERO_QUEST_REWARD_COMPLETED = 2715
+	BACON_HERO_HEROPOWER_QUEST_REWARD_COMPLETED = 2716
+	LETTUCE_FACTION = 2720
+	DEATH_SPELL_OVERRIDE = 2722
+	BACON_IS_BOB_QUEST = 2732
+	BACON_HERO_REWARD_CARD_DBID = 2748
+	BACON_HERO_HEROPOWER_REWARD_CARD_DBID = 2749
+	BACON_HERO_REWARD_MINION_TYPE = 2750
+	BACON_HERO_HEROPOWER_REWARD_MINION_TYPE = 2751
+	MERCENARIES_DISCOVER_SOURCE = 2752
+	HERO_ATTACK_GIVEN_ADDITIONAL = 2776
+	HERO_ARMOR_GIVEN_ADDITIONAL = 2778
+	LETTUCE_CHARGE = 2779
+	BACON_DIED_LAST_COMBAT_HINT = 2780
+	SHIFTING_LOCATION = 2783
+	UNPLAYABLE_VISUALS = 2798
+	CARDTEXT_ENTITY_AS_NUMBERS = 2802
+	BACON_DOUBLE_QUEST_HERO_POWER = 2803
+	MERCENARIES_TREASURE_SCALE_LEVEL = 2810
+	CARD_COSTS_ARMOR = 2811
+	FINALE = 2820
+	OVERHEAL = 2821
+	BACON_BLOODGEMBUFFHEALTHVALUE = 2827
+	EMOTECHARACTER = 2839
+	HAS_ACTIVATE_POWER = 2840
+	EMOTECLASS = 2851
+	VENOMOUS = 2853
+	MAGNETIC_TO_RACE = 2859
+	BACON_MAX_LEADERBOARD_ARMOR = 2867
+	BACON_REBORN_TOOLTIP = 2870
+	BACON_PUTRICIDESCREATION_TOOLTIP = 2875
+	TAG_SCRIPT_DATA_NUM_3 = 2889
+	CARD_NAME_DATA_1 = 2890
+	BACON_COSTS_HEALTH_TO_BUY = 2911
+	TAG_SCRIPT_DATA_NUM_4 = 2919
+	TAG_SCRIPT_DATA_NUM_5 = 2920
+	TAG_SCRIPT_DATA_NUM_6 = 2921
+	DECK_SWAP_ACTIVE = 2929
+	MAX_SIDEBOARD_CARDS = 2931
+	BONUSEFFECTS = 2934
+	BACON_USE_COIN_BASED_BUDDY_METER = 2935
+	BACON_BUY_BUDDY = 2937
+	BACON_BUY_BUDDY_2 = 2938
+	BACON_SHOW_HEROPOWER_BUDDY_AS_EVOLVING_BIG_CARD = 2943
+	HIDDEN_CHOICE_OVERRIDE = 2946
+	BUILDING_UP = 3016
+	BACON_PAIR_CANDIDATE = 3031
+	BACON_TRIGGER_UPBEAT = 3046
+	BACON_TRIGGER_XY = 3047
+	FAN_LINK = 3052
 
 	InvisibleDeathrattle = 335
 	ImmuneToSpellpower = 349
@@ -652,6 +822,7 @@ class GameTag(IntEnum):
 	LocalizationNotes = 344
 
 	# Renamed
+	BACON_FREEZE = BACON_FREEZE_TOOLTIP
 	BACON_HIGHLIGHT_ATTACKING_MINION_DURING_COMBAT = HIGHLIGHT_ATTACKING_MINION_DURING_COMBAT
 	BACON_USE_FAST_ANIMATIONS = USE_FAST_ACTOR_TRANSITION_ANIMATIONS
 	CANT_BE_DAMAGED = IMMUNE
@@ -659,6 +830,7 @@ class GameTag(IntEnum):
 	CANT_BE_TARGETED_BY_ABILITIES = CANT_BE_TARGETED_BY_SPELLS
 	DEATH_RATTLE = DEATHRATTLE
 	DEATHRATTLE_SENDS_BACK_TO_DECK = DEATHRATTLE_RETURN_ZONE
+	DISABLE_GOLDEN_ANIMATIONS = DISABLE_NONHERO_GOLDEN_ANIMATIONS
 	EXTRA_DEATHRATTLES = EXTRA_MINION_DEATHRATTLES_BASE
 	HAND_REVEALED = ZONES_REVEALED
 	HEALING_DOUBLE = SPELL_HEALING_DOUBLE
@@ -666,6 +838,7 @@ class GameTag(IntEnum):
 	KAZAKUS_POTION_POWER_1 = MODULAR_ENTITY_PART_1
 	KAZAKUS_POTION_POWER_2 = MODULAR_ENTITY_PART_2
 	LINKEDCARD = LINKED_ENTITY
+	MODULAR = MAGNETIC
 	RECALL = OVERLOAD
 	RECALL_OWED = OVERLOAD_OWED
 	RED_MANA_CRYSTALS = RED_MANA_GEM
@@ -677,6 +850,7 @@ class GameTag(IntEnum):
 
 	# Deleted
 	IGNORE_DAMAGE = 1
+	GOLD_REWARD_STATE = 13
 	COPY_DEATHRATTLE = 55
 	COPY_DEATHRATTLE_INDEX = 56
 	CARD_ID = 186
@@ -716,10 +890,15 @@ class GameTag(IntEnum):
 	EXTRA_SPELL_CASTS_BASE = 1140
 	EXTRA_OVERLOAD_SPELL_CASTS_BASE = 1272
 	EXTRA_SPELL_CASTS_ADDITIONAL = 1348
+	BACON_MINION_IS_LEVEL_TWO = 1421
+	AVFACTION = 2323
+	AVRANK = 2324
+	MERCS_DISCOVER = 2665
 
 	# Missing/guessed, only present in logs
 	WEAPON = 334
 	DISCARD_CARDS = 890
+	BATTLEGROUNDS_HERO_ARMOR_TIER = 1723
 	BATTLEGROUNDS_DARKMOON_PRIZE_TURN = 1735
 
 	CANT_BE_EXHAUSTED = 244
@@ -848,48 +1027,55 @@ class CardSet(IntEnum):
 	BLANK = 9
 	DEBUG_SP = 10
 	PROMO = 11
-	NAXX = 12
-	GVG = 13
-	BRM = 14
-	TGT = 15
+	NAXX = 12  # Curse of Naxxramas
+	GVG = 13  # Goblins vs Gnomes
+	BRM = 14  # Blackrock Mountain
+	TGT = 15  # The Grand Tournament
 	CREDITS = 16
 	HERO_SKINS = 17
-	TB = 18
+	TB = 18  # Tavern Brawl
 	SLUSH = 19
-	LOE = 20
-	OG = 21
+	LOE = 20  # The League of Explorers
+	OG = 21  # Whispers of the Old Gods
 	OG_RESERVE = 22
-	KARA = 23
+	KARA = 23  # One Night in Karazhan
 	KARA_RESERVE = 24
-	GANGS = 25
+	GANGS = 25  # Mean Streets of Gadgetzan
 	GANGS_RESERVE = 26
-	UNGORO = 27
-	ICECROWN = 1001
-	LOOTAPALOOZA = 1004
-	GILNEAS = 1125
-	BOOMSDAY = 1127
-	TROLL = 1129
-	DALARAN = 1130
-	ULDUM = 1158
-	DRAGONS = 1347
+	UNGORO = 27  # Journey to Un'Goro
+	ICECROWN = 1001  # Knights of the Frozen Throne
+	LOOTAPALOOZA = 1004  # Kobolds & Catacombs
+	GILNEAS = 1125  # The Witchwood
+	BOOMSDAY = 1127  # The Boomsday Project
+	TROLL = 1129  # Rastakhan's Rumble
+	DALARAN = 1130  # Rise of Shadows
+	ULDUM = 1158  # Saviours of Uldum
+	DRAGONS = 1347  # Descent of Dragons
 	YEAR_OF_THE_DRAGON = 1403
-	BLACK_TEMPLE = 1414
+	BLACK_TEMPLE = 1414  # Ashes of Outlands
 	WILD_EVENT = 1439
-	SCHOLOMANCE = 1443
+	SCHOLOMANCE = 1443  # Scholomance Academy
 	BATTLEGROUNDS = 1453
 	DEMON_HUNTER_INITIATE = 1463
-	DARKMOON_FAIRE = 1466
-	THE_BARRENS = 1525
+	DARKMOON_FAIRE = 1466  # Madness at the Darkmoon Faire
+	THE_BARRENS = 1525  # Forged in the Barrens
 	WAILING_CAVERNS = 1559
-	STORMWIND = 1578
-	LETTUCE = 1586
+	STORMWIND = 1578  # United in Stormwind
+	LETTUCE = 1586  # Mercenaries
+	ALTERAC_VALLEY = 1626  # Fractured in Alterac Valley
 	LEGACY = 1635
 	CORE = 1637
 	VANILLA = 1646
+	THE_SUNKEN_CITY = 1658  # Voyage to the Sunken City
+	REVENDRETH = 1691  # Murder at Castle Nathria
 	MERCENARIES_DEV = 1705
+	RETURN_OF_THE_LICH_KING = 1776
+	BATTLE_OF_THE_BANDS = 1809
+	PATH_OF_ARTHAS = 1869
 
 	# Not actually present...
 	TAVERNS_OF_TIME = 1143
+	PLACEHOLDER_202204 = 1810
 
 	# Aliased from the original enums
 	FP1 = 12
@@ -925,11 +1111,23 @@ class CardSet(IntEnum):
 			CardSet.SCHOLOMANCE,
 			CardSet.DARKMOON_FAIRE,
 			CardSet.THE_BARRENS,
-			CardSet.LEGACY
+			CardSet.ALTERAC_VALLEY,
+			CardSet.LEGACY,
+			CardSet.THE_SUNKEN_CITY,
+			CardSet.RETURN_OF_THE_LICH_KING,
+			CardSet.PATH_OF_ARTHAS,
+			CardSet.BATTLE_OF_THE_BANDS,
 		)
 
 	@property
 	def name_global(self):
+		# Newer sets use a 2-3 letter set code
+		from .utils import CARDSET_GLOBAL_STRING_MAP
+		custom = CARDSET_GLOBAL_STRING_MAP.get(self)
+		if custom:
+			return custom
+
+		# Older sets used the enum name
 		return "GLOBAL_CARD_SET_%s" % (self.name)
 
 	@property
@@ -938,7 +1136,7 @@ class CardSet(IntEnum):
 
 	@property
 	def is_standard(self):
-		return self in ZodiacYear.GRYPHON.standard_card_sets
+		return self in ZodiacYear.HYDRA.standard_card_sets
 
 
 class CardType(IntEnum):
@@ -959,10 +1157,23 @@ class CardType(IntEnum):
 	GAME_MODE_BUTTON = 12
 	MOVE_MINION_HOVER_TARGET = 22
 	LETTUCE_ABILITY = 23
+	BATTLEGROUND_HERO_BUDDY = 24
+	LOCATION = 39
+	BATTLEGROUND_QUEST_REWARD = 40
 
 	# Renamed
 	ABILITY = SPELL
 
+	@property
+	def playable(self):
+		return self in (
+			CardType.HERO,
+			CardType.MINION,
+			CardType.SPELL,
+			CardType.WEAPON,
+			CardType.LOCATION,
+		)
+
 	@property
 	def craftable(self):
 		return self in (
@@ -970,6 +1181,7 @@ class CardType(IntEnum):
 			CardType.MINION,
 			CardType.SPELL,
 			CardType.WEAPON,
+			CardType.LOCATION,
 		)
 
 	@property
@@ -1111,6 +1323,15 @@ class PlayReq(IntEnum):
 	REQ_TARGET_MUST_HAVE_TAG = 117
 	REQ_TRADEABLE = 119
 	REQ_NOT_LEGENDARY_TARGET = 123
+	REQ_MINIMUM_TAVERN_TIER_LEVEL_TO_PLAY = 128
+	REQ_CARD_TAVERN_TIER_LEVEL_TO_PLAY = 129
+	REQ_NOT_EXHAUSTED_LOCATION = 130
+	REQ_LOCATION_TARGET = 131
+	REQ_TARGET_SILVER_HAND_RECRUIT = 132
+	REQ_MINIMUM_CORPSES = 133
+	REQ_LOCATION_OR_MINION_TARGET = 134
+	REQ_CAN_BE_TARGETED_BY_LOCATIONS = 135
+	REQ_HAS_PLAYED_SPELL_THIS_GAME = 136
 	REQ_DRAG_TO_PLAY = 999
 
 	# Renamed
@@ -1159,6 +1380,17 @@ class Race(IntEnum):
 	TREANT = 84
 	OWLKIN = 85
 	HALFORC = 88
+	LOCK = 89
+	NAGA = 92
+	OLDGOD = 93
+	PANDAREN = 94
+	GRONN = 95
+	CELESTIAL = 96
+	GNOLL = 97
+	GOLEM = 98
+	HARPY = 99
+	VULPERA = 100
+	# When adding a new race, ensure you also update utils.RACE_TAG_MAP
 
 	# Aliased
 	PET = 20
@@ -1179,18 +1411,42 @@ class Race(IntEnum):
 		"""Whether this Race appears as a minion pool in Battlegrounds matches."""
 		return self in BATTLEGROUNDS_RACES
 
+	@property
+	def race_tag(self):
+		from .utils import CARDRACE_TAG_MAP
+		return CARDRACE_TAG_MAP.get(self)
+
+	@staticmethod
+	def get_race_for_game_tag(game_tag):
+		from .utils import REVERSE_CARDRACE_TAG_MAP
+		return REVERSE_CARDRACE_TAG_MAP.get(game_tag)
+
+	@property
+	def text_order(self):
+		return (
+			RACE_TEXT_ORDER.index(self) if self in RACE_TEXT_ORDER
+			# Sort the others to the end, but keep enum order
+			else len(RACE_TEXT_ORDER) + int(self)
+		)
+
 
 VISIBLE_RACES = [
 	Race.MURLOC, Race.DEMON, Race.MECHANICAL, Race.ELEMENTAL, Race.BEAST,
 	Race.TOTEM, Race.PIRATE, Race.DRAGON, Race.ALL,
 ]
 
+# The order in which the races appear on cards
+RACE_TEXT_ORDER = [
+	Race.UNDEAD, Race.ELEMENTAL, Race.MECHANICAL, Race.DEMON, Race.MURLOC, Race.QUILBOAR,
+	Race.NAGA, Race.PET, Race.DRAGON, Race.TOTEM, Race.PIRATE
+]
+
 # All minion types that may appear as a minion pool in Battlegrounds matches.
-# As of May 2021 matches will always contain five of these. Some are guaranteed to appear
+# As of May 2022 matches will always contain five of these. Some are guaranteed to appear
 # in every match.
 BATTLEGROUNDS_RACES = [
 	Race.MURLOC, Race.DEMON, Race.MECHANICAL, Race.BEAST, Race.DRAGON,
-	Race.PIRATE, Race.ELEMENTAL, Race.QUILBOAR,
+	Race.PIRATE, Race.ELEMENTAL, Race.QUILBOAR, Race.NAGA, Race.UNDEAD,
 ]
 
 
@@ -1379,6 +1635,7 @@ class GameType(IntEnum):
 	GT_MERCENARIES_PVE_COOP = 32
 	GT_MERCENARIES_AI_VS_AI = 33
 	GT_MERCENARIES_FRIENDLY = 34
+	GT_BATTLEGROUNDS_AI_VS_AI = 35
 
 	# GT_LAST = 35
 
@@ -1445,7 +1702,7 @@ class GameType(IntEnum):
 
 
 class BnetRegion(IntEnum):
-	"""bgs.constants.BnetRegion"""
+	"""Blizzard.GameService.SDK.Client.Integration/BnetRegion"""
 
 	REGION_UNINITIALIZED = -1,
 	REGION_UNKNOWN = 0
@@ -1483,6 +1740,8 @@ class BnetRegion(IntEnum):
 		)
 
 
+# Deleted
+
 class GoldRewardState(IntEnum):
 	"""TAG_GOLD_REWARD_STATE"""
 
@@ -1687,6 +1946,7 @@ class BlockType(IntEnum):
 	REVEAL_CARD = 10
 	GAME_RESET = 11
 	MOVE_MINION = 12
+	TRADE = 13
 
 	# Removed
 	SCRIPT = 4
@@ -1778,11 +2038,19 @@ class Booster(IntEnum):
 	STANDARD_WARLOCK = 637
 	STANDARD_DEMONHUNTER = 638
 	GOLDEN_DARKMOON_FAIRE = 643
+	ALTERAC_VALLEY = 665
 	GOLDEN_THE_BARRENS = 686
 	YEAR_OF_THE_PHOENIX = 688
+	THE_SUNKEN_CITY = 694
 	STANDARD_PACK = 713
 	WILD_PACK = 714
 	GOLDEN_STANDARD_PACK = 716
+	REVENDRETH = 729
+	STORMWIND_GOLDEN = 737
+	RETURN_OF_THE_LICH_KING = 821
+	ALTERAC_VALLEY_GOLDEN = 841
+	BATTLE_OF_THE_BANDS = 854
+	PATH_OF_ARTHAS = 903
 
 	# Renamed
 	KOBOLDS_CATACOMBS = KOBOLDS_AND_CATACOMBS
@@ -1815,8 +2083,8 @@ class CardTextBuilderType(IntEnum):
 	GALAKROND_COUNTER = 8
 	DECORATE = 9
 	PLAYER_TAG_THRESHOLD = 10
-	DEPRECATED_11 = 11
-	DEPRECATED_12 = 12
+	ENTITY_TAG_THRESHOLD = 11
+	MULTIPLE_ENTITY_NAMES = 12
 	GAMEPLAY_STRING = 13
 	ZOMBEAST = 14
 	ZOMBEAST_ENCHANTMENT = 15
@@ -1833,12 +2101,19 @@ class CardTextBuilderType(IntEnum):
 	SCRIPT_DATA_NUM_1_NUM_2 = 26
 	POWERED_UP = 27
 	MULTIPLE_ALT_TEXT_SCRIPT_DATA_NUMS = 28
+	REFERENCE_SCRIPT_DATA_NUM_1_ENTITY_POWER = 29
+	REFERENCE_SCRIPT_DATA_NUM_1_CARD_DBID = 30
+	REFERENCE_SCRIPT_DATA_NUM_CARD_RACE = 31
+	BG_QUEST = 32
+	MULTIPLE_ALT_TEXT_SCRIPT_DATA_NUMS_REF_SDN6_CARD_DBID = 33
 
 	# Renamed
 	DEPRECATED_5 = PRIMORDIAL_WAND
 	DEPRECATED_6 = ALTERNATE_CARD_TEXT
 	DEPRECATED_8 = GALAKROND_COUNTER
 	DEPRECATED_10 = PLAYER_TAG_THRESHOLD
+	DEPRECATED_11 = ENTITY_TAG_THRESHOLD
+	DEPRECATED_12 = MULTIPLE_ENTITY_NAMES
 	KAZAKUS_POTION = MODULAR_ENTITY
 	PLACEHOLDER_01 = REFERENCE_SCRIPT_DATA_NUM_1_NUM_2_ENTITY
 	PLACE_HOLDER_02 = UNDATAKAH_ENCHANT
@@ -1927,6 +2202,12 @@ class RewardType(IntEnum):
 	MERCENARY_MERCENARY = 23
 	MERCENARY_RANDOM_MERCENARY = 24
 	MERCENARY_KNOCKOUT = 25
+	BATTLEGROUNDS_GUIDE_SKIN = 26
+	BATTLEGROUNDS_HERO_SKIN = 27
+	BATTLEGROUNDS_FINISHER = 28
+	BATTLEGROUNDS_BOARD_SKIN = 29
+	BATTLEGROUNDS_EMOTE = 30
+	MERCENARY_RENOWN = 31
 
 
 # Deleted
@@ -2103,6 +2384,8 @@ class ZodiacYear(IntEnum):
 	DRAGON = 4
 	PHOENIX = 5
 	GRYPHON = 6
+	HYDRA = 7
+	WOLF = 8
 
 	@property
 	def standard_card_sets(self):
